//
//  ViewController.m
//  ApplePayDemo
//
//  Created by lanouhn on 16/6/5.
//  Copyright © 2016年 llp. All rights reserved.
//

#import "ViewController.h"
#import <PassKit/PassKit.h>

@interface ViewController ()<PKPaymentAuthorizationViewControllerDelegate>

@end

@implementation ViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    
    //创建支付的按钮
    PKPaymentButton *payButton = [PKPaymentButton buttonWithType:PKPaymentButtonTypePlain style:PKPaymentButtonStyleBlack];
    payButton.center = self.view.center;
    [payButton addTarget:self action:@selector(payAction:) forControlEvents:UIControlEventTouchUpInside];
    [self.view addSubview:payButton];
    
    
}
//点击支付按钮响应的事件
- (void)payAction:(PKPaymentButton *)sneder {
    
   //判断设备是否支持ApplePay
    if ([PKPaymentAuthorizationViewController canMakePayments]) {
        //设备支持
        //1.创建支付请求
        PKPaymentRequest *request = [[PKPaymentRequest alloc] init];
        //设置支付的地区 HK
        request.countryCode = @"CN";
        //设置币种 HKD 香港  CNY 大陆
        request.currencyCode = @"CNY";
        //限制支付卡或者是商家所支持的卡的类型
//        PKEncryptionSchemeECC_V2
//        PKPaymentNetworkAmex,美国运通
//        PKPaymentNetworkChinaUnionPay,中国银联
//        PKPaymentNetworkDiscover,
//        PKPaymentNetworkInterac,
//        PKPaymentNetworkMasterCard,万事达信用卡
//        PKPaymentNetworkPrivateLabel,
//        PKPaymentNetworkVisa Visa卡
        request.supportedNetworks = @[PKPaymentNetworkVisa, PKPaymentNetworkChinaUnionPay];
        //商家的支付能力
//        PKMerchantCapability3DS
//        PKMerchantCapabilityEMV 中国银联   Visa卡  万事达信用卡
//        PKMerchantCapabilityCredit
//        PKMerchantCapabilityDebit
        request.merchantCapabilities = PKMerchantCapability3DS | PKMerchantCapabilityEMV;
        //设置商户ID
        request.merchantIdentifier = @"";
        //需要的配送的信息以及账单的信息
        request.requiredBillingAddressFields = PKAddressFieldAll;
        request.requiredShippingAddressFields = PKAddressFieldAll;
        //运输方式
        NSDecimalNumber *decimalNumber = [NSDecimalNumber decimalNumberWithString:@"11.0"];
        PKShippingMethod *method = [PKShippingMethod summaryItemWithLabel:@"快递公司" amount:decimalNumber];
        method.detail = @"24小时之内送到";
        method.identifier = @"SF";//快递公司的标示
        request.shippingMethods = @[method];//快递公司配置信息
        request.shippingType = PKShippingTypeServicePickup;
        //2.存储额外信息  applicationData  这个存储一些你的应用中， 关于这次支付的唯一标示信息，比如:一个购物车中的商品ID，在用户授权后这个applicationData的希望值就会出现在这次支付的Token中
        request.applicationData = [@"商品ID:123454"dataUsingEncoding:NSUTF8StringEncoding];
        //3.商品的支付页面信息
        PKPaymentSummaryItem *item = [PKPaymentSummaryItem summaryItemWithLabel:@"iOS" amount:[NSDecimalNumber decimalNumberWithString:@"100.0"]];
        PKPaymentSummaryItem *item1 = [PKPaymentSummaryItem summaryItemWithLabel:@"html5" amount:[NSDecimalNumber decimalNumberWithString:@"100.0"]];
        PKPaymentSummaryItem *item2 = [PKPaymentSummaryItem summaryItemWithLabel:@"蓝欧" amount:[NSDecimalNumber decimalNumberWithString:@"200.0"]];
        request.paymentSummaryItems = @[item, item1, item2];
        //4显示支付的页面
        PKPaymentAuthorizationViewController *paymentVC = [[PKPaymentAuthorizationViewController alloc] initWithPaymentRequest:request];
        paymentVC.delegate = self;
        [self presentViewController:paymentVC animated:YES completion:nil];
    }else {
        NSLog(@"设备不支持ApplePay");
    }
    
    
}
//支付过程中
- (void)paymentAuthorizationViewController:(PKPaymentAuthorizationViewController *)controller
                       didAuthorizePayment:(PKPayment *)payment
                                completion:(void (^)(PKPaymentAuthorizationStatus status))completion {
    //payment:支付的对象。支付的信息都在他的身上  1.token, 当时创建这个payment的时候，都可以在这个位置拿到信息，价格，地址，快递公司，描述，都可以拿到。。。。。
    //PKPaymentAuthorizationStatus : 认证状态
    //completion: 一个回调的block， 直接影响到支付界面的结果显示的状态
//    PKPaymentAuthorizationStatusSuccess, // Merchant auth'd (or expects to auth) the transaction successfully.  交易成功
//    PKPaymentAuthorizationStatusFailure, // Merchant failed to auth the transaction. 没有授权交易或者说认证失败
    
//    PKPaymentAuthorizationStatusInvalidBillingPostalAddress,   商户拒绝账单地址
//    PKPaymentAuthorizationStatusInvalidShippingPostalAddress,  商户拒绝收货地址
//    PKPaymentAuthorizationStatusInvalidShippingContact,        提供的信息不足
//    PKPaymentAuthorizationStatusPINRequired    交易需要指纹输入
//    PKPaymentAuthorizationStatusPINIncorrect   指纹输入不正确
//    PKPaymentAuthorizationStatusPINLockout   输入次数超出
    PKPaymentToken *token = payment.token;
    NSLog(@"%@", token);
    //地址
    NSString *address = payment.billingContact.postalAddress.city;
    //这个位置     我们开发人员，需要把token 值已经支付订单信息上传到公司的服务器，也就是调用一下公司的后台数据接口，进行请求信息，根据后台返回给我们的支付信息调用block
    //根据后台返回给我们支付成功的状态码 让completion  block调用对应的枚举值
    //如：
    BOOL paySuccess = YES;//后台返回的支付结果状态码
    if (paySuccess) {
        completion(PKPaymentAuthorizationStatusSuccess);
    }else {
        completion(PKPaymentAuthorizationStatusFailure);
    }
    
}
- (void)paymentAuthorizationViewControllerDidFinish:(PKPaymentAuthorizationViewController *)controller {
    //点击右上角的取消按钮之后的操作
    [self dismissViewControllerAnimated:YES completion:nil];
}
- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

@end
